@@ -1,215 +1,211 @@
-/*
- * kpooka.cpp. Part of the KDE project (I hope).
- * By Mr. Bogus (paulrahme@yahoo.com)
- * These files modified from kdesdk/kexample/ - big wet ones go over there.
- * Also huge amounts of thanks to Antonio Larrosa for all the help with kde/qt.
- * Also also thanks to Eggert Ehmke for helping with bugfixes, modifications and translations.
- */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <qfiledlg.h>
 #include "kpooka.h"
-#include <qfile.h>
-#include <qmsgbox.h>
-#include <qkeycode.h>
-#include <kiconloader.h>
-#include <unistd.h>
-#include <iostream.h>
+#include <kfiledialog.h>
+#include <kapp.h>
 #include <kmenubar.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <qtextview.h>
 
 FILE *theFile;
 QString DATADIR;
 
-KPooka::KPooka()
+KPooka::KPooka ()
 {
-// Make a pixmap in the main window
-	block1 = new Block( this, "block1" );
-	block1->setBackgroundColor( QColor( 255, 255, 255) );
-	block1->show();
-	setView(block1, FALSE);
-
-// Make "file->quit" menu & put it into the menubar
-	QPopupMenu* p = new QPopupMenu;
-	p->insertItem(i18n("&Quit"), kapp, SLOT(quit()), CTRL+Key_Q);
-	menuBar()->insertItem(i18n("&File"), p);
-	menuBar()->insertSeparator();
+// Make "Game" menu & put it into the menubar
+	QPopupMenu *gamemenu = new QPopupMenu;
+	gamemenu->insertItem(i18n("&New"), this, SLOT(backToLevel1()));
+	gamemenu->insertItem( i18n( "&Quit" ), kapp, SLOT(quit()), CTRL+Key_Q );
 
 // Make "Level" menu & put it into the menubar
-	QPopupMenu* p2 = new QPopupMenu;
-	p2->insertItem(i18n("&Restart"), this, SLOT(restartLevel()), Key_Escape);
-	p2->insertItem(i18n("&Next"), this, SLOT(nextLevel()), Key_N);
-	p2->insertItem(i18n("&Back to Level 1"), this, SLOT(backToLevel1()));
-	menuBar()->insertItem(i18n("&Level"), p2);
-	menuBar()->insertSeparator();
+	QPopupMenu* levelmenu = new QPopupMenu;
+	levelmenu->insertItem(i18n("&Restart"), this, SLOT(restartLevel()), Key_Escape);
+	levelmenu->insertItem(i18n("&Next"), this, SLOT(nextLevel()), Key_N);
 
-// eggert.ehmke@berlin.de
 // Make "Options" menu
-	OptionMenu.setCheckable (true);
-	QuickModeID = OptionMenu.insertItem (i18n("Quick mode"), this, SLOT (quickMode()), 0);
-	menuBar()->insertItem(i18n("&Options"), &OptionMenu);
-	menuBar()->insertSeparator();
+//	QPopupMenu* optionsmenu = new QPopupMenu;
+	optionsmenu = new QPopupMenu;
+	optionsmenu->setCheckable (true);
+	QuickModeID = optionsmenu->insertItem (i18n("Quick mode"), this, SLOT (quickMode()), 0);
 
-// generate a KDE-style help menu
-	p = kapp->getHelpMenu(true,
-		i18n("\"KPooka\"\n"
-		"by Mr. Bogus (paulrahme@yahoo.com)\n"
-		"KPooka compiled for the K Desktop Environment."));
-	menuBar()->insertItem(i18n("&Help"), p);
+	QString about =
+	i18n("kpooka 1.0\n\n"
+		"(c) 2000 Mr. Bogus\n"
+		"paulrahme@yahoo.com\n"
+		"This game comes with ABSOLUTELY NO WARRANTY\n"
+		"This is free software, and you are welcome to redistribute it\n"
+		"under certain conditions\n");
 
-	KConfig *kconf = kapp->getConfig();
-	if (kconf)
-	{
-		kconf->setGroup("general");
-		maxLevel = kconf->readNumEntry("Level");
-		bQuickMode = kconf->readBoolEntry ("QuickMode");
-		OptionMenu.setItemChecked (QuickModeID, bQuickMode);
-		if (maxLevel == 0)	// make sure at least the first level is read
-			maxLevel = 1;	// eggert.ehmke@berlin.de
-	}
-	else
-	{
-		maxLevel = 1;
-	}
-	theLevel = 0;
+	QPopupMenu *helpmenu = helpMenu( about );
+	KMenuBar *menu = new KMenuBar( this );
+	menu->insertItem(i18n("&Game"), gamemenu);
+	menu->insertItem(i18n("&Level"), levelmenu);
+	menu->insertItem(i18n("&Options"), optionsmenu);
+	menu->insertSeparator();
+	menu->insertItem( i18n( "&Help" ), helpmenu);
+	setMenu( menu );
+
+// Make a pixmap in the main window
+        block1 = new Block( this, "block1" );
+        block1->setBackgroundColor( QColor( 255, 255, 255) );
+        block1->show();
+        setView(block1, FALSE);
+
+	KConfig *kconf = kapp->config();
+        if (kconf)
+        {
+                kconf->setGroup("General");
+                maxLevel = kconf->readNumEntry("Level");
+                bQuickMode = kconf->readBoolEntry ("QuickMode");
+                optionsmenu->setItemChecked (QuickModeID, bQuickMode);
+                if (maxLevel == 0)      // make sure at least the first level is read
+                        maxLevel = 1;   // eggert.ehmke@berlin.de
+        }
+        else
+        {
+                maxLevel = 1;
+        }
+        theLevel = 0;
 	while (theLevel < maxLevel)
-		readLevel ();
-};
+		readLevel();
+}
 
 void KPooka::readLevel()
 {
-        
+
 // grab the width & height of the level
-        
         char theText[50];
         int temp;
         bool oneTeleportFound = 0;
         // exit gracefully if the level file is read to end of file
         // eggert.ehmke@berlin.de
-	fgets(theText, 50, theFile);
-	if ( strlen(theText) < 2 )
+        fgets(theText, 50, theFile);
+        if ( strlen(theText) < 2 )
         {
-                QMessageBox::information(this, i18n("Congratulations !!"),
-                                        i18n("You solved all the levels.\n\
-Now it's your turn ! Invent some more and send them to me.\n\
+                KMessageBox::information(this, i18n("Congratulations !! \
+You solved all the levels.\n\
+Now it's your turn ! Design some more and send them to me.\n\
 Mr. Bogus (paulrahme@yahoo.com)"));
-                return;
+
+		return;
         }
-	// eggert.ehmke@berlin.de
-	// insert the level number into the caption bar
-	QString caption;
-	caption.sprintf ("KPooka level %d : %s", theLevel+1, theText);
-	setCaption (caption);
+        // eggert.ehmke@berlin.de
+        // insert the level number into the caption bar
+	theText[strlen(theText)-1]=0;
+        QString caption;
+        caption.sprintf ("KPooka level %d : %s", theLevel+1, theText);
+        setCaption (caption);
         fscanf(theFile, "%i", &temp);
         block1->level_width=temp;
         fscanf(theFile, "%i", &temp);
         block1->level_height=temp;
 // make sure the teleports are by default way off the screen in case there are none on this level
-	block1->teleport_position[0][0]=500;
-	block1->teleport_position[0][1]=500;
-	block1->teleport_position[1][0]=500;
-	block1->teleport_position[1][1]=500;
+        block1->teleport_position[0][0]=500;
+        block1->teleport_position[0][1]=500;
+        block1->teleport_position[1][0]=500;
+        block1->teleport_position[1][1]=500;
 
-// read the level itself in from the file
+   // read the level itself in from the file
 /*
-	0 = blank
-	2 = start (red block)
-	5 = teleport
-	9 = exit
-	10 = normal (green) block
-	11 = unmovable (grey/cement) block
+        0 = blank
+        2 = start (red block)
+        5 = teleport
+        9 = exit
+        10 = normal (green) block
+        11 = unmovable (grey/cement) block
 */
 
-	for (int i=0; i<block1->level_height; i++)
-	{
+        for (int i=0; i<block1->level_height; i++)
+        {
+//printf("\n");
 		for (int j=0; j<block1->level_width; j++)
-		{
-			fscanf(theFile,"%i", &temp);
-			block1->level[j][i]=temp;
-			block1->backuplevel[j][i]=temp;
-			if (temp==2) // startpos
-			{
-				block1->x=j;
-				block1->y=i;
-				block1->start_position[0]=j;
-				block1->start_position[1]=i;
-			}
-			if (temp == 5) // teleport
-			{
-				if  (oneTeleportFound)
-				{
-					block1->teleport_position[1][0]=j;
-					block1->teleport_position[1][1]=i;
-				} else
-				{
-					block1->teleport_position[0][0]=j;
-					block1->teleport_position[0][1]=i;
-					oneTeleportFound = 1;
-				}					
-			}
-			if (temp==9) // exit
-			{
-				block1->exit_position[0]=j;
-				block1->exit_position[1]=i;
-			}
-		}
-	}
-	fgetc(theFile); fgetc(theFile); // read the end of the last line and the blank line after the level
-	// resize the window to fit & shrinkwrap around the level
-	block1->setMinimumSize( block1->level_width*30, block1->level_height*30 );
-	block1->setMaximumSize( block1->level_width*30, block1->level_height*30 );
-	block1->resize(block1->level_width*30,block1->level_height*30);
-	setMinimumSize( block1->level_width*30, block1->level_height*30+30 );
-	resize(block1->level_width*30,block1->level_height*30+30);
-	update();
+                {
+                        fscanf(theFile,"%i", &temp);
+//printf("%i ",temp);
+                        block1->level[j][i]=temp;
+                        block1->backuplevel[j][i]=temp;
+                        if (temp==2) // startpos
+                        {
+                                block1->x=j;
+                                block1->y=i;
+                                block1->start_position[0]=j;
+                                block1->start_position[1]=i;
+                        }
+                        if (temp == 5) // teleport
+                        {
+                                if  (oneTeleportFound)
+                                {
+                                        block1->teleport_position[1][0]=j;
+                                        block1->teleport_position[1][1]=i;
+                                } else
+                                {
+                                        block1->teleport_position[0][0]=j;
+                                        block1->teleport_position[0][1]=i;
+                                        oneTeleportFound = 1;
+                                }
+                        }
+                        if (temp==9) // exit
+                        {
+                                block1->exit_position[0]=j;
+                                block1->exit_position[1]=i;
+                        }
+                }
+        }
+        fgetc(theFile); fgetc(theFile); // read the end of the last line and the blank line after the level
+        // resize the window to fit & shrinkwrap around the level
+        block1->setMinimumSize( block1->level_width*30, block1->level_height*30 );
+        block1->setMaximumSize( block1->level_width*30, block1->level_height*30 );
+        block1->resize(block1->level_width*30,block1->level_height*30);
+        setMinimumSize( block1->level_width*30, block1->level_height*30+29 );
+//        resize(block1->level_width*30,block1->level_height*30+29);
+        resize(0,0);
+        update();
+
+        theLevel++;
 
-	theLevel++;
-	
 };
 
 void KPooka::backToLevel1()
 {
-	rewind(theFile);
-	theLevel=0;
-	readLevel();
+        rewind(theFile);
+        theLevel=0;
+        readLevel();
 }
 
 void KPooka::nextLevel()
 {
-	if (theLevel<maxLevel)
-		readLevel();
+        if (theLevel<maxLevel)
+                readLevel();
 }
 
 void KPooka::restartLevel()
 {
-	for (int i=0; i<block1->level_height; i++)
-		for (int j=0; j<block1->level_width; j++)
-			block1->level[j][i] = block1->backuplevel[j][i];
-	block1->x=block1->start_position[0];
-	block1->y=block1->start_position[1];
-	block1->repaint(FALSE);
+        for (int i=0; i<block1->level_height; i++)
+                for (int j=0; j<block1->level_width; j++)
+                        block1->level[j][i] = block1->backuplevel[j][i];
+        block1->x=block1->start_position[0];
+        block1->y=block1->start_position[1];
+        block1->repaint(FALSE);
 }
 
 void KPooka::quickMode ()
 {
-	bQuickMode = !bQuickMode;
-	OptionMenu.setItemChecked (QuickModeID, bQuickMode);
-	KConfig *kconf = kapp->getConfig();
-	kconf->setGroup("general");
-	kconf->writeEntry("QuickMode", bQuickMode);
+        bQuickMode = !bQuickMode;
+        optionsmenu->setItemChecked (QuickModeID, bQuickMode);
+	KConfig *kconf = kapp->config();
+        kconf->setGroup("General");
+        kconf->writeEntry("QuickMode", bQuickMode);
 }
 
 bool KPooka::queryExit()
 {
-	return TRUE;
+        return TRUE;
 
-	// hmmm.. this does still not work, it quits anyway
-/*	bool result = QMessageBox::critical(this, i18n("Really?"),
-						 i18n("Do you really want to quit?"), 
-						 QMessageBox::Yes,
-						 QMessageBox::No) == QMessageBox::Yes;
-	return result;
+        // hmmm.. this does still not work, it quits anyway
+/*      bool result = QMessageBox::critical(this, i18n("Really?"),
+                                                 i18n("Do you really want to quit?"),
+                                                 QMessageBox::Yes,
+                                                 QMessageBox::No) == QMessageBox::Yes;
+        return result;
 */};
 
 void KPooka::keyPressEvent( QKeyEvent *event )
@@ -221,7 +217,7 @@ void KPooka::keyPressEvent( QKeyEvent *event )
 	if ( (block1->x==block1->teleport_position[0][0]) && (block1->y==block1->teleport_position[0][1])
 	  || (block1->x==block1->teleport_position[1][0]) && (block1->y==block1->teleport_position[1][1]) )
 		oldValue=5;
-	
+
 	switch ( event->key() )
 	{
 	case Key_Right:
@@ -484,7 +480,7 @@ void KPooka::keyPressEvent( QKeyEvent *event )
 				block1->repaint(FALSE);
 			}
 		}
-// if it's at the exit...		
+// if it's at the exit...
 		if ( (block1->x==block1->exit_position[0]) && (block1->y==block1->exit_position[1]) )
 		{
 // Animate the red blobby getting sucked down the exit
@@ -521,35 +517,29 @@ void KPooka::keyPressEvent( QKeyEvent *event )
 		readLevel();
 		if (theLevel>maxLevel)
 		{
-			KConfig *kconf = kapp->getConfig();
-			kconf->setGroup("general");
+			KConfig *kconf = kapp->config();
+			kconf->setGroup("General");
 			kconf->writeEntry("Level", theLevel);
 		}
 		block1->repaint(FALSE);
 	}
 };
 
-
-int main(int argc, char* argv[]) {
-
-	KApplication a(argc,argv);
-	DATADIR=a.kde_datadir() + "/kpooka/";
+int main( int argc, char **argv )
+{
+	KApplication a( argc, argv, "kpooka");
 
 // Open the level file...
-	theFile = fopen(DATADIR+"level.dat","ro");
+	theFile = fopen(KGlobal::dirs()->findResource("appdata","level.dat"),"ro");
 	if ( theFile == NULL )
-	   { fprintf(stderr, "Cannot open level.dat\n"); exit(1); }
+		{ fprintf(stderr, "Cannot open level.dat, theFile = %i\n",theFile); }
+//		{ fprintf(stderr, "Cannot open level.dat, theFile = %i\n",theFile); exit(1); }
 
+	KPooka *kpooka=new KPooka();
+//	kpooka->resize( 400, 300 );
 
-// New kpooka...
-	KPooka* kpooka = new KPooka ();
-	if ( kpooka == NULL )
-	   { fprintf(stderr, "Creating kpooka object failed!\n"); exit(2); }
-	
+	a.setMainWidget( kpooka );
 	kpooka->show();
 
-	a.exec();
-
-// Close up
-	fclose(theFile);
+	return a.exec();
 }
