@@ -1,35 +1,37 @@
 /*
  * kpooka.h. Part of the KDE project.
  * By Mr. Bogus (paulrahme@yahoo.com)
- * These files originally modified from kdesdk/kexample/ - big wet ones go over there.
+ * These files originally modified from Antonio Larrosa's p3 tutorial - big wet ones go over there.
  */
 
+#include <ktmainwindow.h>
 #include "pix.h"
 #include <kapp.h>
 #include <ktmainwindow.h>
 #include <kurl.h>
 #include <qmlined.h>
-#include <kfm.h>
 #include <unistd.h>
 #include <kconfig.h>
 
 #define frameDelay 6000
 
-class KPooka : public KTMainWindow {
-	Q_OBJECT
+class KPooka : public KTMainWindow
+{
+  Q_OBJECT
 public:
 	KPooka();
 	~KPooka(){};
+
 public slots:
 	void restartLevel();
 	void nextLevel();
 	void backToLevel1();
 	void quickMode ();
+
 protected:
 	void KPooka::keyPressEvent( QKeyEvent *event );
 	void KPooka::doMove(int x, int y);
 private:
-	KFM* kfm;
 	enum {TOOLBAR_EXIT, TOOLBAR_OPEN};
 	Block *block1;
 	bool queryExit();
@@ -39,5 +41,7 @@ private:
 	KConfig *kconf;
 	bool bQuickMode;
 	int QuickModeID;
-	QPopupMenu OptionMenu;
+	QPopupMenu* optionsmenu;
 };
+
+
