@@ -10,6 +10,9 @@
 #include <stdio.h>
 #include <qapplication.h>
 #include <qpainter.h>
+#include <kglobal.h>
+#include <kstddirs.h>
+#include <kconfig.h>
 
 class Block : public QWidget
 {
